using System;
using System.Collections.Generic;
using System.Windows.Forms;
using PhoenixCommander.GUI;
using Components.SplashBar;
using PhoenixDLL.Class;
using System.IO;
using System.Data.OleDb;
using PhoenixDLL.GUI;
using PhoenixDLL.RegistryConfiguration;
using PhoenixStatistics.Class;
using Utils.Log;

namespace PhoenixCommander
{
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            MeetingSet ms = new MeetingSet();
            StatManager sm = new StatManager();
            try
            {
                Application.EnableVisualStyles();
                Application.SetCompatibleTextRenderingDefault(false);

                #region Chargement des rendez-vous
                RegistryManager rm = new RegistryManager(PhoenixSuite.Phoenix);


                rm.ProcessRegistry();
                ms.Path = Options.GetInstance().Path;
            }
            catch (FileNotFoundException)
            {
                MessageBox.Show("La base de donnes n'a pas t trouve. Veuillez indiquer son emplacement...",
                    "Attention", MessageBoxButtons.OK, MessageBoxIcon.Asterisk);
                OpenFileDialog ofd = new OpenFileDialog();
                ofd.Title = "Slection de la base de donnes...";
                DialogResult dr = ofd.ShowDialog();

                if (dr == DialogResult.OK)
                {
                    Options.GetInstance().Path = ofd.FileName;
                    ms.Path = Options.Instance.Path;
                }
                else
                    return;
            }
            catch (Exception ex)
            {
                Log.Instance.Write(ex.Message, "PhoenixCommander.Program()", LogType.Erreur);
                MessageBox.Show("Une erreur est intervenue.\r\n" + ex.Message, "Erreur",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            try
            {
                SplashBar.ShowSplash(9, 0, 1);
                SplashBar.PerformStep();

                fr_Main fr = new fr_Main();
                SplashBar.PerformStep();

                ms.Fill();
                SplashBar.PerformStep();

                sm.CalculateMeetingOnMonth();
                SplashBar.PerformStep();

                sm.CalculateAges();
                SplashBar.PerformStep();

                sm.CalculateWomenAges();
                SplashBar.PerformStep();

                sm.CalculateMenAges();
                SplashBar.PerformStep();

                sm.CalculateAllCount();
                SplashBar.PerformStep();

                sm.CalculateAllAverageAges();
                SplashBar.PerformStep();

                SplashBar.CloseSplash();

                fr.StatManager = sm;
                fr.MeetingSet = ms;
                Application.Run(fr);
            }
            catch (OleDbException ex)
            {
                Log.Instance.Write(ex.Message, "PhoenixCommander.Program.Main()", LogType.Erreur);
                SplashBar.CloseSplash();
                DialogResult dr = MessageBox.Show("Une erreur est apparue au niveau de la base de donnes. La plus part du temps c'est" +
                    " parce que ce n'est pas la bonne base de donnes qui a t selectionne dans les options\r\n(" + ex.Message
                    + ")\r\nVoulez-vous ouvrir le menu d'options?", "Attention",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Asterisk);
                if (dr == DialogResult.No) return;
                else
                {
                    fr_Options fr = new fr_Options();
                    fr.StartPosition = FormStartPosition.CenterScreen;
                    fr.ShowDialog();
                }
            }

            catch (Exception ex)
            {
                MessageBox.Show("Une erreur est intervenue.\r\n" + ex.Message + "\r\nRedmarrer et si cela se reproduit, contactez votre administrateur", "Erreur",
                     MessageBoxButtons.OK, MessageBoxIcon.Error);
                SplashBar.CloseSplash();

            }

                #endregion
        }
    }
}